@@ -27,6 +27,7 @@ add_overall <- function(x, last, col_label) {
 #' @rdname add_overall
 #' @export
 add_overall.tbl_summary <- function(x, last = FALSE, col_label = NULL) {
+  updated_call_list <- c(x$call_list, list(add_overall = match.call()))
   # checking that input x has a by var
   if (is.null(x$inputs[["by"]])) {
     stop(
@@ -49,20 +50,24 @@ add_overall.tbl_summary <- function(x, last = FALSE, col_label = NULL) {
     do.call(tbl_summary, x_copy$inputs) %>%
     pluck("table_body")
 
-  add_overall_merge(x, overall, last, col_label)
+  x <- add_overall_merge(x, overall, last, col_label)
+
+  x$call_list <- updated_call_list
+  x
 }
 
 
 add_overall_merge <- function(x, overall, last, col_label) {
   # checking the original tbl_summary and the added overall,
   # are the same before binding (excluding headers)
-  if (!identical(select(x$table_body, c("row_type", "variable", "label")),
-                 select(overall, c("row_type", "variable", "label")) %>% as_tibble())) {
+  if (!identical(
+    select(x$table_body, c("row_type", "variable", "label")),
+    select(overall, c("row_type", "variable", "label")) %>% as_tibble()
+  )) {
     paste(
       "An error occured in `add_overall()`, and overall statistics cannot be merged.",
-      "Has the variable label changed since the original call of `tbl_summary()` or",
-      "`tbl_svysummary()`, for example, via `add_stat_label()`?",
-      "If so, run `add_overall()` before the variable label is updated.") %>%
+      "Has the variable label changed since the original call of `tbl_summary()`?"
+    ) %>%
       stringr::str_wrap() %>%
       stop(call. = FALSE)
   }
@@ -83,20 +88,19 @@ add_overall_merge <- function(x, overall, last, col_label) {
       )
   }
 
-  # updating table_header
-  x$table_header <- table_header_fill_missing(x$table_header, x$table_body)
-
-  # adding header
-  col_label <- col_label %||% paste0("**", translate_text("Overall"), "**, N = {style_number(N)}")
-  x <- modify_header(x, stat_0 = col_label)
-
-  # adding footnote to overall column (only if a consistent footnote appears in other stat cols)
-  consistent_footnote <-
-    filter(x$table_header, startsWith(.data$column, "stat_") & .data$column != "stat_0") %>%
-    pull(.data$footnote) %>%
-    unique()
-  if (length(consistent_footnote) == 1)
-    x$table_header$footnote[x$table_header$column == "stat_0"] <- consistent_footnote
+  # updating table_style
+  x <-
+    modify_table_styling(
+      x,
+      columns = "stat_0",
+      footnote = footnote_stat_label(x$meta_data),
+      hide = FALSE
+    ) %>%
+    modify_header(
+      stat_0 =
+        col_label %||%
+          paste0("**", translate_text("Overall"), "**, N = {style_number(N)}"),
+    )
 
   x
 }
@@ -105,6 +109,7 @@ add_overall_merge <- function(x, overall, last, col_label) {
 #' @rdname add_overall
 #' @export
 add_overall.tbl_svysummary <- function(x, last = FALSE, col_label = NULL) {
+  updated_call_list <- c(x$call_list, list(add_overall = match.call()))
   # checking that input x has a by var
   if (is.null(x$inputs[["by"]])) {
     stop(
@@ -127,5 +132,8 @@ add_overall.tbl_svysummary <- function(x, last = FALSE, col_label = NULL) {
     do.call(tbl_svysummary, x_copy$inputs) %>%
     pluck("table_body")
 
-  add_overall_merge(x, overall, last, col_label)
+  x <- add_overall_merge(x, overall, last, col_label)
+
+  x$call_list <- updated_call_list
+  x
 }
