@@ -29,12 +29,11 @@
 #'   tbl_summary(by = trt) %>%
 #'   bold_labels() %>%
 #'   as_kable()
-
 as_kable <- function(x, include = everything(), return_calls = FALSE,
                      exclude = NULL, ...) {
   # DEPRECATION notes ----------------------------------------------------------
   if (!rlang::quo_is_null(rlang::enquo(exclude))) {
-    lifecycle::deprecate_warn(
+    lifecycle::deprecate_stop(
       "1.2.5",
       "gtsummary::as_kable(exclude = )",
       "as_kable(include = )",
@@ -46,31 +45,31 @@ as_kable <- function(x, include = everything(), return_calls = FALSE,
     )
   }
 
-  # creating list of kable calls --------------------------------------------------
-  kable_calls <-
-    table_header_to_kable_calls(x = x, ...)
-  if (return_calls == TRUE) return(kable_calls)
+  # running pre-conversion function, if present --------------------------------
+  x <- do.call(get_theme_element("pkgwide-fun:pre_conversion", default = identity), list(x))
 
-  # converting to charcter vector ----------------------------------------------
+  # converting row specifications to row numbers, and removing old cmds --------
+  x <- .clean_table_styling(x)
+
+  # creating list of kable calls -----------------------------------------------
+  kable_calls <-
+    table_styling_to_kable_calls(x = x, ...)
+  if (return_calls == TRUE) {
+    return(kable_calls)
+  }
+
+  # converting to character vector ---------------------------------------------
   include <-
     .select_to_varnames(
       select = {{ include }},
       var_info = names(kable_calls),
       arg_name = "include"
     )
-  exclude <-
-    .select_to_varnames(
-      select = {{ exclude }},
-      var_info = names(kable_calls),
-      arg_name = "exclude"
-    )
 
   # making list of commands to include -----------------------------------------
   # this ensures list is in the same order as names(x$kable_calls)
   include <- names(kable_calls) %>% intersect(include)
-
   # user cannot exclude the first 'kable' command
-  include <- include %>% setdiff(exclude)
   include <- "tibble" %>% union(include)
 
   # taking each kable function call, concatenating them with %>% separating them
@@ -84,27 +83,26 @@ as_kable <- function(x, include = everything(), return_calls = FALSE,
     eval()
 }
 
-table_header_to_kable_calls <- function(x, ...) {
+table_styling_to_kable_calls <- function(x, ...) {
   dots <- rlang::enexprs(...)
 
-  table_header <- .clean_table_header(x$table_header)
+  kable_calls <- table_styling_to_tibble_calls(x, col_labels = FALSE)
 
-  kable_calls <- as_tibble(x, return_calls = TRUE, include = -c("cols_label"))
 
   # fmt_missing ----------------------------------------------------------------
-  kable_calls[["fmt_missing"]] <- expr(dplyr::mutate_all(~ifelse(is.na(.), "", .)))
+  kable_calls[["fmt_missing"]] <- expr(dplyr::mutate_all(~ ifelse(is.na(.), "", .)))
 
   # kable ----------------------------------------------------------------------
   df_col_labels <-
-    dplyr::filter(table_header, .data$hide == FALSE)
+    dplyr::filter(x$table_styling$header, .data$hide == FALSE)
 
-  if (!is.null(x$list_output$caption))
+  if (!is.null(x$table_styling$caption)) {
     kable_calls[["kable"]] <-
-    expr(knitr::kable(caption = !!x$list_output$caption, col.names = !!df_col_labels$label, !!!dots))
-  else
+      expr(knitr::kable(caption = !!x$table_styling$caption, col.names = !!df_col_labels$label, !!!dots))
+  } else {
     kable_calls[["kable"]] <-
-    expr(knitr::kable(col.names = !!df_col_labels$label, !!!dots))
+      expr(knitr::kable(col.names = !!df_col_labels$label, !!!dots))
+  }
 
   kable_calls
 }
-
