@@ -30,8 +30,7 @@ print.gtsummary <- function(x, print_engine = NULL, ...) {
   }
 
   # printing results
-  switch(
-    print_engine,
+  switch(print_engine,
     "gt" = as_gt(x),
     "kable" = as_kable(x),
     "flextable" = as_flex_table(x),
@@ -59,17 +58,17 @@ knit_print.gtsummary <- function(x, ...) {
   # PDF uses kable as default printer (is_latex_output catches pdf_document and beamer...maybe more?)
   else if (is.null(print_engine) && knitr::is_latex_output() == TRUE) {
     rlang::inform(paste(
-        "Table printed with `knitr::kable()`, not {gt}. Learn why at",
-        "http://www.danieldsjoberg.com/gtsummary/articles/rmarkdown.html",
-        "To suppress this message, include `message = FALSE` in code chunk header.",
-        sep = "\n"
+      "Table printed with `knitr::kable()`, not {gt}. Learn why at",
+      "http://www.danieldsjoberg.com/gtsummary/articles/rmarkdown.html",
+      "To suppress this message, include `message = FALSE` in code chunk header.",
+      sep = "\n"
     ))
     print_engine <- "kable"
   }
 
   # don't use word_document with gt engine
   else if (identical(print_engine %||% "gt", "gt") &&
-           "docx" %in% knitr::opts_knit$get('rmarkdown.pandoc.to')) {
+    "docx" %in% knitr::opts_knit$get("rmarkdown.pandoc.to")) {
     if (requireNamespace("flextable", quietly = TRUE)) {
       rlang::inform(paste(
         "Table printed with {flextable}, not {gt}. Learn why at",
@@ -77,7 +76,8 @@ knit_print.gtsummary <- function(x, ...) {
         "To suppress this message, include `message = FALSE` in the code chunk header.",
         sep = "\n"
       ))
-      print_engine <- "flextable"    }
+      print_engine <- "flextable"
+    }
     else {
       rlang::inform(paste(
         "Table printed with `knitr::kable()`, not {gt}. Learn why at",
@@ -91,7 +91,7 @@ knit_print.gtsummary <- function(x, ...) {
 
   # RTF warning when using gt
   else if (identical(print_engine %||% "gt", "gt") &&
-           "rtf" %in% knitr::opts_knit$get('rmarkdown.pandoc.to')) {
+    "rtf" %in% knitr::opts_knit$get("rmarkdown.pandoc.to")) {
     rlang::inform(paste(
       "Table printed with `knitr::kable()`, not {gt}. Learn why at",
       "http://www.danieldsjoberg.com/gtsummary/articles/rmarkdown.html",
@@ -105,8 +105,7 @@ knit_print.gtsummary <- function(x, ...) {
   else if (is.null(print_engine)) print_engine <- "gt"
 
   # printing gtsummary table with appropriate engine
-  switch(
-    print_engine,
+  switch(print_engine,
     "gt" = as_gt(x),
     "kable" = as_kable(x),
     "flextable" = as_flex_table(x),
@@ -114,6 +113,5 @@ knit_print.gtsummary <- function(x, ...) {
     "huxtable" = as_hux_table(x),
     "tibble" = as_tibble(x)
   ) %>%
-      knitr::knit_print()
+    knitr::knit_print()
 }
-
