@@ -59,21 +59,24 @@
 #' # Example 3 ----------------------------------
 #' # Pass a list of survfit() objects
 #' tbl_survfit_ex3 <-
-#'   list(survfit(Surv(ttdeath, death) ~ 1, trial),
-#'        survfit(Surv(ttdeath, death) ~ trt, trial)) %>%
+#'   list(
+#'     survfit(Surv(ttdeath, death) ~ 1, trial),
+#'     survfit(Surv(ttdeath, death) ~ trt, trial)
+#'   ) %>%
 #'   tbl_survfit(times = c(12, 24))
 #'
 #' # Example 4 Competing Events Example ---------
 #' # adding a competing event for death (cancer vs other causes)
+#' set.seed(1123)
 #' library(dplyr, warn.conflicts = FALSE, quietly = TRUE)
 #' trial2 <- trial %>%
 #'   mutate(
-#'   death_cr = case_when(
-#'     death == 0 ~ "censor",
-#'     runif(n()) < 0.5 ~ "death from cancer",
-#'     TRUE ~ "death other causes"
-#'   ) %>% factor()
-#' )
+#'     death_cr = case_when(
+#'       death == 0 ~ "censor",
+#'       runif(n()) < 0.5 ~ "death from cancer",
+#'       TRUE ~ "death other causes"
+#'     ) %>% factor()
+#'   )
 #'
 #' survfit_cr_ex4 <-
 #'   survfit(Surv(ttdeath, death_cr) ~ grade, data = trial2) %>%
@@ -123,9 +126,10 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
     #   details = "`label=` argument no longer accepts a single string. Pass formula list.")
   }
   assert_package("survival", "tbl_survfit()")
-  if (purrr::every(x, ~!inherits(.x, "survfit"))) {
+  if (purrr::every(x, ~ !inherits(.x, "survfit"))) {
     stop("Argument `x=` must be class 'survfit' created from the `survival::survfit()` function.",
-         call. = FALSE)
+      call. = FALSE
+    )
   }
 
   if (c(is.null(times), is.null(probs)) %>% sum() != 1) {
@@ -133,7 +137,8 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
   }
   if (!rlang::is_string(statistic) || !rlang::is_string(label_header %||% "")) {
     stop("`statistic=` and `label_header=` arguments must be strings of length one.",
-         call. = FALSE)
+      call. = FALSE
+    )
   }
   if (reverse == TRUE && !is.null(probs)) {
     rlang::inform("`reverse=TRUE` argument ignored for survival quantile estimation.")
@@ -143,13 +148,13 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
   estimate_type <- ifelse(is.null(times), "probs", "times")
   estimate_fun <-
     estimate_fun %||%
-    switch(
-      estimate_type,
+    switch(estimate_type,
       probs = getOption("gtsummary.tbl_survfit.probs.estimate_fun") %||%
         partial(style_sigfig, digits = 2),
       times = getOption("gtsummary.tbl_survfit.times.estimate_fun") %||%
         partial(style_percent, symbol = TRUE)
-    )
+    ) %>%
+    gts_mapper("tbl_survfit(estimate_fun=)")
 
   # will return call, and all object passed to in tbl_summary call -------------
   # the object func_inputs is a list of every object passed to the function
@@ -178,51 +183,56 @@ tbl_survfit.list <- function(x, times = NULL, probs = NULL,
     )
 
   meta_data <-
-    meta_to_df_stats(meta_data, inputs = tbl_survfit_inputs,
-                     estimate_type = estimate_type, estimate_fun = estimate_fun,
-                     missing = missing, statistic = statistic)
+    meta_to_df_stats(meta_data,
+      inputs = tbl_survfit_inputs,
+      estimate_type = estimate_type, estimate_fun = estimate_fun,
+      missing = missing, statistic = statistic
+    )
 
   # checking that the variable list is unique
   if (quiet == FALSE && !identical(meta_data$variable, unique(meta_data$variable))) {
-    paste("tbl_survfit: The variable list in `.$meta_data` is not unique.",
-          "This could pose a problem with  subsequent `tbl_survfit` calls,",
-          "e.g. `tbl_survfit() %>% add_p()`") %>%
+    paste(
+      "tbl_survfit: The variable list in `.$meta_data` is not unique.",
+      "This could pose a problem with  subsequent `tbl_survfit` calls,",
+      "e.g. `tbl_survfit() %>% add_p()`"
+    ) %>%
       stringr::str_wrap() %>%
       rlang::inform()
   }
 
-  # table_header ---------------------------------------------------------------
+  # table_body -----------------------------------------------------------------
   table_body <-
     meta_data %>%
     select(.data$var_label, .data$table_body) %>%
     unnest(.data$table_body) %>%
     select(.data$variable, .data$var_label, everything())
-  table_header <-
-    tibble(column = names(table_body)) %>%
-    table_header_fill_missing()
 
   # finishing up ---------------------------------------------------------------
   # constructing final result
-  results <- list(
-    table_body = table_body,
-    table_header = table_header,
-    meta_data = meta_data,
-    inputs = tbl_survfit_inputs,
-    call_list = list(tbl_survfit = match.call())
-  )
+  x <-
+    .create_gtsummary_object(
+      table_body = table_body,
+      meta_data = meta_data,
+      inputs = tbl_survfit_inputs
+    )
 
   # applying labels
-  lbls <- as.list(unique(meta_data$df_stats[[1]]$col_label)) %>% set_names(unique(meta_data$df_stats[[1]]$col_name))
-  results <-
-    expr(modify_header(results, label = !!paste0("**", translate_text("Characteristic"), "**"), !!!lbls)) %>%
+  lbls <-
+    meta_data$df_stats[[1]] %>%
+    select(.data$col_name, .data$col_label) %>%
+    distinct() %>%
+    tibble::deframe() %>%
+    as.list()
+
+  x <-
+    expr(modify_header(x, label = !!paste0("**", translate_text("Characteristic"), "**"), !!!lbls)) %>%
     eval()
 
   # exporting results ----------------------------------------------------------
-  results$inputs <- tbl_survfit_inputs
-  results$call_list = list(tbl_survfit = match.call())
-  class(results) <- c("tbl_survfit", "gtsummary")
+  x$call_list <- list(tbl_survfit = match.call())
+  class(x) <- c("tbl_survfit", "gtsummary")
 
-  results
+  x
 }
 
 #' @export
@@ -235,9 +245,11 @@ tbl_survfit.survfit <- function(x, ...) {
 #' @export
 #' @rdname tbl_survfit
 tbl_survfit.data.frame <- function(x, y, include = everything(), ...) {
-  include <- dplyr::select(x, {{include}}) %>% names()
+  include <- dplyr::select(x, {{ include }}) %>% names()
 
   # checking inputs ------------------------------------------------------------
+  check_haven_labelled(x)
+
   # able to construct Surv() object?
   y <- enexpr(y)
 
@@ -245,9 +257,11 @@ tbl_survfit.data.frame <- function(x, y, include = everything(), ...) {
     tryCatch(
       expr(with(!!x, !!y)) %>% eval(),
       error = function(e) {
-        paste("There was are error constructing the `y = Surv()` object from the",
-              "data frame passed in `x=`, and the outcome passed in `y=`.",
-              "All columns in `y=` should appear in `x=`.\n\n") %>%
+        paste(
+          "There was are error constructing the `y = Surv()` object from the",
+          "data frame passed in `x=`, and the outcome passed in `y=`.",
+          "All columns in `y=` should appear in `x=`.\n\n"
+        ) %>%
           stringr::str_wrap() %>%
           c(as.character(e)) %>%
           stop(call. = FALSE)
@@ -256,14 +270,16 @@ tbl_survfit.data.frame <- function(x, y, include = everything(), ...) {
 
   # Surv object is indeed a of class Surv
   if (!inherits(y_surv, "Surv")) {
-    paste("Together, the data frame in `x=`, and the survival outcome in `y=`",
-          "must construct `Surv` oject, e.g. `with(trial, Surv(ttdeath, death))`") %>%
+    paste(
+      "Together, the data frame in `x=`, and the survival outcome in `y=`",
+      "must construct `Surv` oject, e.g. `with(trial, Surv(ttdeath, death))`"
+    ) %>%
       stringr::str_wrap() %>%
       stop(call. = FALSE)
   }
 
   # getting list of all covariates ---------------------------------------------
-  y_vars <- inject(all.vars(~!!y))
+  y_vars <- inject(all.vars(~ !!y))
   x_vars <- include %>% setdiff(y_vars)
 
   # construct list of survfits -------------------------------------------------
@@ -274,8 +290,10 @@ tbl_survfit.data.frame <- function(x, y, include = everything(), ...) {
         function(.x) expr(survival::survfit(!!y ~ !!sym(.x), data = !!x)) %>% eval()
       ),
       error = function(e) {
-        paste("There was are error constructing the list `survfit()` objects from the",
-              "data frame passed in `x=`, and the outcome passed in `y=`.") %>%
+        paste(
+          "There was are error constructing the list `survfit()` objects from the",
+          "data frame passed in `x=`, and the outcome passed in `y=`."
+        ) %>%
           stringr::str_wrap() %>%
           stop(call. = FALSE)
       }
@@ -291,38 +309,51 @@ meta_to_df_stats <- function(meta_data, inputs, estimate_type, estimate_fun,
     mutate(
       df_stats = pmap(
         # calculating estimates ------------------------------------------------
-        list(.data$survfit, .data$variable, .data$tidy),
-        ~ switch(
-          estimate_type,
-          "times" = survfit_time(..1, variable = ..2, times = inputs$times,
-                                 label_header = inputs$label_header,
-                                 conf.level = inputs$conf.level,
-                                 reverse = inputs$reverse,
-                                 quiet = inputs$quiet, tidy = ..3),
-          "probs" = survfit_prob(..1, variable = ..2, probs = inputs$probs,
-                                 label_header = inputs$label_header,
-                                 conf.level = inputs$conf.level,
-                                 quiet = inputs$quiet, tidy = ..3)
+        list(.data$survfit, .data$variable, .data$tidy, .data$var_label),
+        ~ switch(estimate_type,
+          "times" = survfit_time(..1,
+            variable = ..2, times = inputs$times,
+            label_header = inputs$label_header,
+            conf.level = inputs$conf.level,
+            reverse = inputs$reverse,
+            quiet = inputs$quiet, tidy = ..3,
+            var_label = ..4
+          ),
+          "probs" = survfit_prob(..1,
+            variable = ..2, probs = inputs$probs,
+            label_header = inputs$label_header,
+            conf.level = inputs$conf.level,
+            quiet = inputs$quiet, tidy = ..3,
+            var_label = ..4
+          )
         )
       ),
-      # table_body -----------------------------------------------------------------
+      # table_body -------------------------------------------------------------
       table_body = map2(
         .data$df_stats, .data$var_label,
         function(df_stats, var_label) {
-          strata <- intersect("strata", names(df_stats)) %>% list() %>% compact()
+          strata <- intersect("strata", names(df_stats)) %>%
+            list() %>%
+            compact()
 
           table_body <-
             df_stats %>%
-            mutate_at(vars(.data$estimate, .data$conf.low, .data$conf.high),
-                      ~ coalesce(as.character(estimate_fun(.)), missing)) %>%
+            mutate_at(
+              vars(.data$estimate, .data$conf.low, .data$conf.high),
+              ~ coalesce(as.character(estimate_fun(.)), missing)
+            ) %>%
             mutate(
               statistic = glue(.env$statistic) %>% as.character(),
-              row_type = switch(length(strata) == 0, "label") %||% "level"
+              row_type = switch(length(strata) == 0,
+                "label"
+              ) %||% "level"
             ) %>%
             select(c("variable", "row_type", "label", "col_name", "statistic")) %>%
-            tidyr::pivot_wider(id_cols = c(.data$variable, .data$row_type, .data$label),
-                               names_from = c(.data$col_name),
-                               values_from = c(.data$statistic))
+            tidyr::pivot_wider(
+              id_cols = c(.data$variable, .data$row_type, .data$label),
+              names_from = c(.data$col_name),
+              values_from = c(.data$statistic)
+            )
 
           # adding label row, if needed
           if (nrow(table_body) > 1) {
@@ -330,8 +361,10 @@ meta_to_df_stats <- function(meta_data, inputs, estimate_type, estimate_fun,
               table_body %>%
               select(.data$variable) %>%
               distinct() %>%
-              mutate(row_type = "label",
-                     label = var_label) %>%
+              mutate(
+                row_type = "label",
+                label = var_label
+              ) %>%
               bind_rows(table_body)
           }
           table_body
@@ -341,14 +374,16 @@ meta_to_df_stats <- function(meta_data, inputs, estimate_type, estimate_fun,
 }
 
 # calculates and prepares survival quantile estimates for tbl
-survfit_prob <- function(x, variable, probs, label_header, conf.level, quiet, tidy) {
-
-  strata <- intersect("strata", names(tidy)) %>% list() %>% compact()
+survfit_prob <- function(x, variable, probs, label_header, conf.level, quiet,
+                         tidy, var_label) {
+  strata <- intersect("strata", names(tidy)) %>%
+    list() %>%
+    compact()
 
   # calculating survival quantiles, and adding estimates to pretty tbl
   df_stat <- purrr::map2_dfr(
     probs, seq_along(probs),
-    ~stats::quantile(x, probs = .x) %>%
+    ~ stats::quantile(x, probs = .x) %>%
       as.data.frame() %>%
       tibble::rownames_to_column() %>%
       set_names(c("strata", "estimate", "conf.low", "conf.high")) %>%
@@ -360,13 +395,16 @@ survfit_prob <- function(x, variable, probs, label_header, conf.level, quiet, ti
     # creating labels
     mutate(
       variable = .env$variable,
-      label = switch(length(.env$strata) == 0, translate_text("Overall")) %||%
+      label = switch(length(.env$strata) == 0,
+        var_label
+      ) %||%
         # take everything to the right of the first '='
         str_sub(strata, str_locate(strata, fixed("="))[1] + 1),
       col_label = .env$label_header %||%
         # for some languages, we show 'Percentile 50%' instead of '50% Percentile'
         switch(get_theme_element("pkgwide-str:language", default = "en") %in% "es",
-               "**{style_percent(prob, symbol = TRUE)} {translate_text('Percentile')}**") %||%
+          "**{style_percent(prob, symbol = TRUE)} {translate_text('Percentile')}**"
+        ) %||%
         "**{style_percent(prob, symbol = TRUE)} {translate_text('Percentile')}**" %>%
         glue() %>% as.character()
     )
@@ -379,9 +417,10 @@ survfit_prob <- function(x, variable, probs, label_header, conf.level, quiet, ti
 
 # calculates and prepares n-year survival estimates for tbl
 survfit_time <- function(x, variable, times, label_header, conf.level,
-                         reverse, quiet, tidy) {
-
-  strata <- intersect("strata", names(tidy)) %>% list() %>% compact()
+                         reverse, quiet, tidy, var_label) {
+  strata <- intersect("strata", names(tidy)) %>%
+    list() %>%
+    compact()
   multi_state <- inherits(x, "survfitms")
   if (multi_state == TRUE) {
     # selecting state to show
@@ -389,8 +428,11 @@ survfit_time <- function(x, variable, times, label_header, conf.level,
       setdiff("(s0)") %>%
       purrr::pluck(1)
 
-    if (identical(quiet, FALSE)) rlang::inform(glue(
-      "tbl_survfit: Multi-state model detected. Showing probabilities into state '{state}'"))
+    if (identical(quiet, FALSE)) {
+      rlang::inform(glue(
+        "tbl_survfit: Multi-state model detected. Showing probabilities into state '{state}'"
+      ))
+    }
 
     tidy <- dplyr::filter(tidy, .data$state == .env$state)
   }
@@ -398,22 +440,26 @@ survfit_time <- function(x, variable, times, label_header, conf.level,
   # adding time 0 to data frame
   tidy <-
     tidy %>%
+    # making strata a fct to preserve ordering
+    mutate_at(vars(!!!strata), ~ factor(., levels = unique(.))) %>%
     # if CI is missing, and SE is 0, making the CIs the estimate
-    mutate_at(vars(.data$conf.high, .data$conf.low),
-              ~ifelse(is.na(.) & .data$std.error == 0, .data$estimate, .)) %>%
+    mutate_at(
+      vars(.data$conf.high, .data$conf.low),
+      ~ ifelse(is.na(.) & .data$std.error == 0, .data$estimate, .)
+    ) %>%
     select(any_of(c("time", "estimate", "conf.high", "conf.low", "strata"))) %>%
     bind_rows(
       group_by(., !!!syms(strata)) %>%
         slice(1) %>%
-        mutate(time = 0,
-               estimate = ifelse(multi_state, 0, 1),
-               conf.low = ifelse(multi_state, 0, 1),
-               conf.high = ifelse(multi_state, 0, 1))
+        mutate(
+          time = 0,
+          estimate = ifelse(multi_state, 0, 1),
+          conf.low = ifelse(multi_state, 0, 1),
+          conf.high = ifelse(multi_state, 0, 1)
+        )
     ) %>%
     ungroup()
 
-
-
   # getting requested estimates
   df_stat <-
     tidy %>%
@@ -424,7 +470,7 @@ survfit_time <- function(x, variable, times, label_header, conf.level,
     # adding in timepoints requested by user
     full_join(
       select(tidy, !!!syms(strata)) %>%
-        distinct()  %>%
+        distinct() %>%
         mutate(
           time = list(.env$times),
           col_name = list(paste("stat", seq_len(length(.env$times)), sep = "_"))
@@ -436,22 +482,30 @@ survfit_time <- function(x, variable, times, label_header, conf.level,
     arrange(!!!syms(strata), .data$time) %>%
     group_by(!!!syms(strata)) %>%
     tidyr::fill(.data$estimate, .data$conf.high, .data$conf.low,
-                .data$time_max, .direction = "down") %>%
+      .data$time_max,
+      .direction = "down"
+    ) %>%
     ungroup() %>%
     # keeping obs of user-specified times
     filter(!is.na(.data$col_name)) %>%
     # if user-specified time is after the latest follow-up time, making it NA
-    mutate_at(vars(.data$estimate, .data$conf.high, .data$conf.low),
-              ~ifelse(.data$time > .data$time_max, NA_real_, .)) %>%
+    mutate_at(
+      vars(.data$estimate, .data$conf.high, .data$conf.low),
+      ~ ifelse(.data$time > .data$time_max, NA_real_, .)
+    ) %>%
     mutate(
       variable = .env$variable,
-      label = switch(length(.env$strata) == 0, translate_text("Overall")) %||%
+      label = switch(length(.env$strata) == 0,
+        var_label
+      ) %||%
         # take everything to the right of the first '='
         str_sub(strata, str_locate(strata, fixed("="))[1] + 1),
       col_label = .env$label_header %||% paste0("**", translate_text("Time"), " {time}**") %>% glue() %>% as.character()
     ) %>%
-    select(any_of(c("variable", "label", "strata", "col_name", "col_label")),
-           everything(), -.data$time_max)
+    select(
+      any_of(c("variable", "label", "strata", "col_name", "col_label")),
+      everything(), -.data$time_max
+    )
 
   # converting to reverse probs, if requested
   if (reverse == TRUE) {
@@ -476,13 +530,15 @@ survfit_to_var <- function(survfit_list, stratified, tidy, quiet) {
       }
       var <- word(tidy$strata[1], 1, sep = fixed("="))
       if (quiet == FALSE &&
-          # if you have more than one equal sign
-          stringr::str_count(tidy$strata[1], pattern = fixed("=")) > 1 &&
-          # there are more than one "word" with sep = ", ", then you likely have more than one var
-          stringr::str_count(tidy$strata[1], pattern = fixed(", ")) >= 1) {
-        paste("The `tbl_survfit()` function supports `survfit()` objects with a",
-              "single stratifying variable, and it looks like you may have more.",
-              "Errors or unexpected output may occur.") %>%
+        # if you have more than one equal sign
+        stringr::str_count(tidy$strata[1], pattern = fixed("=")) > 1 &&
+        # there are more than one "word" with sep = ", ", then you likely have more than one var
+        stringr::str_count(tidy$strata[1], pattern = fixed(", ")) >= 1) {
+        paste(
+          "The `tbl_survfit()` function supports `survfit()` objects with a",
+          "single stratifying variable, and it looks like you may have more.",
+          "Errors or unexpected output may occur."
+        ) %>%
           str_wrap() %>%
           inform()
       }
@@ -496,16 +552,23 @@ survfit_to_label <- function(survfit_list, varlist, stratified, label) {
   purrr::pmap_chr(
     list(survfit_list, varlist, seq_along(survfit_list), stratified),
     function(x, v, i, stratified) {
-      if (!is.null(label[[v]])) return(label[[v]])
-      if (stratified == FALSE) return("Overall")
+      if (!is.null(label[[v]])) {
+        return(label[[v]])
+      }
+      if (stratified == FALSE) {
+        return(translate_text("Overall"))
+      }
 
       # try to extra label from data (if exists)
-      data <- x$call %>% as.list() %>% pluck("data")
+      data <- x$call %>%
+        as.list() %>%
+        pluck("data")
       label <- NULL
       if (!is.null(data)) {
-        label <-  tryCatch(rlang::eval_tidy(data)[[v]] %>% attr("label"),
-                           warning = function(w) NULL,
-                           error = function(e) NULL)
+        label <- tryCatch(rlang::eval_tidy(data)[[v]] %>% attr("label"),
+          warning = function(w) NULL,
+          error = function(e) NULL
+        )
       }
 
       # if couldn't get label from data, set variable name as label
@@ -514,3 +577,19 @@ survfit_to_label <- function(survfit_list, varlist, stratified, label) {
   )
 }
 
+safe_survfit_eval <- function(x) {
+  tryCatch(
+    eval(x),
+    error = function(e) {
+      paste(
+        "There was an error executing {.code add_n()} or {.code add_p()}.",
+        "The error may be a due to the construction of the original",
+        "{.code survival::survfit()} object.",
+        "Please visit this help file for a possible solution:",
+        "{.code ?tbl_survfit_errors}"
+      ) %>%
+        cli_alert_danger()
+      e
+    }
+  )
+}
