@@ -7,7 +7,9 @@ knitr::opts_chunk$set(
 )
 
 ## ---- echo = FALSE, results = 'asis'------------------------------------------
-if (!identical(Sys.getenv("NOT_CRAN"), "true")) {
+# we do NOT want the vignette to build on CRAN...it's taking too long
+if (!identical(Sys.getenv("IN_PKGDOWN"), "true") && 
+    !tolower(as.list(Sys.info())$user) %in% c("sjobergd", "currym", "whitingk")) {
   msg <- 
     paste("View this vignette on the",
           "[package website](http://www.danieldsjoberg.com/gtsummary/articles/gallery.html).")
