@@ -1,27 +1,27 @@
-context("test-add_n")
-testthat::skip_on_cran()
+skip_on_cran()
 
 mod <- lm(age ~ marker + grade, trial)
 
 test_that("no errors/warnings with tidy_standardize", {
+  skip_if(!require("effectsize"))
   expect_error(tbl_regression(mod, tidy_fun = tidy_standardize), NA)
-  expect_warning(tbl_regression(mod, tidy_fun = tidy_standardize), NA)
 })
 
 test_that("no errors/warnings with tidy_bootstrap", {
+  skip_if(!require("parameters"))
   expect_error(tbl_regression(mod, tidy_fun = tidy_bootstrap), NA)
   expect_warning(tbl_regression(mod, tidy_fun = tidy_bootstrap), NA)
 })
 
 
 test_that("no errors/warnings with pool_and_tidy_mice", {
+  skip_if(!require("mice"))
   mod_mice <-
     suppressWarnings(mice::mice(trial, m = 2)) %>%
     with(glm(response ~ age + marker + grade, family = binomial))
 
   expect_error(tbl_regression(mod_mice), NA)
-  expect_warning(tbl_regression(mod_mice, exponentiate = TRUE), NA)
-
+  expect_error(mice::pool(mod_mice) %>% tbl_regression(), NA)
   expect_output(mice::pool(mod_mice), NA)
 })
 
@@ -34,5 +34,29 @@ test_that("no errors/warnings with tbl_regression.multinom", {
   )
 })
 
+test_that("no errors/warnings with tbl_regression.gam", {
+  skip_if(!require("mgcv"))
+  mod <- mgcv::gam(response ~ s(marker, age) + grade, data = trial, family = binomial)
 
+  expect_error(
+    mod %>% tidy_gam(),
+    NA
+  )
 
+  # test the exp argument is working
+  expect_equal(
+    mod %>% tidy_gam(exponentiate = TRUE, conf.int = TRUE),
+    mod %>%
+      tidy_gam(exponentiate = FALSE, conf.int = TRUE) %>%
+      dplyr::mutate_at(vars(any_of(c("estimate", "conf.low", "conf.high"))), exp)
+  )
+
+  expect_error(
+    mod %>%
+      tbl_regression(
+        exponentiate = TRUE,
+        label = `s(marker,age)` ~ "Smoothed marker/age"
+      ),
+    NA
+  )
+})
